hash
stringlengths 40
40
| diff
stringlengths 131
26.7k
| message
stringlengths 7
694
| project
stringlengths 5
67
| split
stringclasses 1
value | diff_languages
stringlengths 2
24
|
---|---|---|---|---|---|
7e11252ea5be106b216e6bcb15ff307ca677f7b0 | diff --git a/spec/ronin_spec.rb b/spec/ronin_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/ronin_spec.rb
+++ b/spec/ronin_spec.rb
@@ -3,8 +3,9 @@ require 'ronin/version'
describe Ronin do
it "should have a version" do
- @version = Ronin.const_get('VERSION')
- @version.should_not be_nil
- @version.should_not be_empty
+ version = subject.const_get('VERSION')
+
+ version.should_not be_nil
+ version.should_not be_empty
end
end | More use of 'subject' in specs. | ronin-ruby_ronin | train | rb |
f79bf1568d5b084ba3d72f32bba4af72815be60b | diff --git a/code/administrator/components/com_activities/controllers/activity.php b/code/administrator/components/com_activities/controllers/activity.php
index <HASH>..<HASH> 100644
--- a/code/administrator/components/com_activities/controllers/activity.php
+++ b/code/administrator/components/com_activities/controllers/activity.php
@@ -23,6 +23,8 @@ class ComActivitiesControllerActivity extends ComDefaultControllerDefault
// TODO To be removed as soon as the problem with language files loading on HMVC calls is solved
JFactory::getLanguage()->load('com_activities', JPATH_ADMINISTRATOR);
+
+ $this->registerCallback('before.add', array($this, 'setIp'));
}
protected function _actionPurge(KCommandContext $context)
@@ -46,4 +48,9 @@ class ComActivitiesControllerActivity extends ComDefaultControllerDefault
$context->status = KHttpResponse::NO_CONTENT;
}
}
+
+ public function setIp(KCommandContext $context)
+ {
+ $context->data->ip = KRequest::get('server.REMOTE_ADDR', 'ip');
+ }
}
\ No newline at end of file | Added callback for setting requester IP address before add.
re #<I> | joomlatools_joomlatools-framework | train | php |
89bf89271a387a118e8579cde0fbfa1dc772c40b | diff --git a/js/luno.js b/js/luno.js
index <HASH>..<HASH> 100644
--- a/js/luno.js
+++ b/js/luno.js
@@ -323,6 +323,8 @@ module.exports = class luno extends Exchange {
}
async fetchMyTrades (symbol = undefined, since = undefined, limit = undefined, params = {}) {
+ if (typeof symbol === 'undefined')
+ throw new ExchangeError (this.id + ' fetchMyTrades requires a symbol argument');
await this.loadMarkets ();
let market = this.market (symbol);
let request = { | Adding exception for missing symbol in fetchMyTrades | ccxt_ccxt | train | js |
fe0c368cde9244acc579dbadc5ae0689cf27a3f2 | diff --git a/docker/index.js b/docker/index.js
index <HASH>..<HASH> 100644
--- a/docker/index.js
+++ b/docker/index.js
@@ -88,16 +88,16 @@ function calcFinishStats(stats) {
const parser = new Parser({
environment: new Environment(getEnvOptions()),
});
- const results = await parser.parse(getRules());
+ const data = await parser.parse(getRules());
if (verbose) {
console.log('Work is done');
console.log('Execution time: ' + ((new Date).getTime() - time));
console.log('Results:');
- console.log(util.inspect(results, { showHidden: false, depth: null }));
+ console.log(util.inspect(data, { showHidden: false, depth: null }));
} else {
console.log(JSON.stringify({
- results,
- stats: calcFinishStats(stats),
+ data,
+ stat: calcFinishStats(stats),
}, null, ' '));
}
} catch (e) { | Updated return value in docker cli command
:goose: | redco_goose-parser | train | js |
b727d5802e8090e1bde224a7bd287d769cfd44f1 | diff --git a/src/constants/Style.js b/src/constants/Style.js
index <HASH>..<HASH> 100644
--- a/src/constants/Style.js
+++ b/src/constants/Style.js
@@ -52,6 +52,7 @@ module.exports = {
INCOME: '#133F49',
INVESTMENTS: '#FF7070',
KIDS: '#82D196',
+ OTHER: '#959CA6',
PETS: '#85507B',
PERSONAL_CARE: '#338B7A',
SHOPPING: '#CF5F84', | Adds OTHER as a category color in Style constants | mxenabled_mx-react-components | train | js |
9dbaf13f6af20b1dcd3f76337b74ab006b401cab | diff --git a/spec/unit/provider/ifconfig/debian_spec.rb b/spec/unit/provider/ifconfig/debian_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/unit/provider/ifconfig/debian_spec.rb
+++ b/spec/unit/provider/ifconfig/debian_spec.rb
@@ -52,6 +52,7 @@ describe Chef::Provider::Ifconfig::Debian do
File.should_receive(:new).with(@config_filename_ifaces).and_return(StringIO.new)
File.should_receive(:open).with(@config_filename_ifaces, "w").and_yield(@config_file_ifaces)
File.should_receive(:new).with(@config_filename_ifcfg, "w").and_return(@config_file_ifcfg)
+ File.should_receive(:exist?).with(@config_filename_ifaces).and_return(true)
end
it "should create network-scripts directory" do | Stub that /etc/network/interfaces really is there [on windows] | chef_chef | train | rb |
b048bd729a5e462c5352127bd3cd63ed95dfc8ae | diff --git a/tests/Timer/TimersTest.php b/tests/Timer/TimersTest.php
index <HASH>..<HASH> 100644
--- a/tests/Timer/TimersTest.php
+++ b/tests/Timer/TimersTest.php
@@ -2,7 +2,6 @@
namespace React\Tests\EventLoop\Timer;
-use React\EventLoop\TimerInterface;
use React\Tests\EventLoop\TestCase;
use React\EventLoop\Timer\Timer;
use React\EventLoop\Timer\Timers;
@@ -30,10 +29,8 @@ class TimersTest extends TestCase
{
$timers = new Timers();
- /** @var TimerInterface $timer1 */
- $timer1 = $this->createMock('React\EventLoop\TimerInterface');
- /** @var TimerInterface $timer2 */
- $timer2 = $this->createMock('React\EventLoop\TimerInterface');
+ $timer1 = new Timer(0.1, function () {});
+ $timer2 = new Timer(0.1, function () {});
$timers->add($timer1); | Using a real `Timer` instance, since pre-historic PHPUnit versions are being used in CI | reactphp_event-loop | train | php |
cb0903098fb02f044eae752f3c0aaabcbbd96b14 | diff --git a/tasks/reqs/config.js b/tasks/reqs/config.js
index <HASH>..<HASH> 100644
--- a/tasks/reqs/config.js
+++ b/tasks/reqs/config.js
@@ -80,7 +80,7 @@ var config = {
parentIncludeJs: [
'src/scripts/[^_]*.*'
],
- scss: 'src/stylesheets/**/*.scss',
+ scss: 'src/stylesheets/**/*.{scss, scss.liquid}',
images: 'src/images/*.{png,jpg,gif}',
destAssets: 'dist/assets',
destSnippets: 'dist/snippets', | Add 'scss.liquid' files to watch | Shopify_slate | train | js |
e0195ac0762776ec92508c2ec02b4c0a5e70a73b | diff --git a/salt/modules/cmd.py b/salt/modules/cmd.py
index <HASH>..<HASH> 100644
--- a/salt/modules/cmd.py
+++ b/salt/modules/cmd.py
@@ -22,7 +22,7 @@ DEFAULT_CWD = os.path.expanduser('~')
__outputter__ = {
'run': 'txt',
}
-
+# TODO: Add a way to quiet down the logging here when salt-call -g is ran
def _run(cmd,
cwd=DEFAULT_CWD,
stdout=subprocess.PIPE, | Add a TODO for tomorrow for the new grain __salt__['cmd.run'] code | saltstack_salt | train | py |
51537aed0ade84a943781496c163ef9421c5f949 | diff --git a/jsio/util/browser.js b/jsio/util/browser.js
index <HASH>..<HASH> 100644
--- a/jsio/util/browser.js
+++ b/jsio/util/browser.js
@@ -118,21 +118,22 @@ $.remove = function(el) {
$.cursorPos = function(ev, el) {
var offset = $.pos(el);
- offset.top = ev.clientY - offset.top + document.body.scrollTop;
- offset.left = ev.clientX - offset.left + document.body.scrollLeft;
+ offset.top = ev.clientY - offset.top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop);
+ offset.left = ev.clientX - offset.left + (window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft);
return offset;
}
$.pos = function(el) {
var parent = el;
var offset = {top: 0, left: 0};
- do {
+ while(parent && parent != document.body) {
offset.left += parent.offsetLeft;
offset.top += parent.offsetTop;
while(parent.offsetParent != parent.parentNode) {
offset.top -= parent.scrollTop; offset.left -= parent.scrollLeft;
parent = parent.parentNode;
}
- } while((parent = parent.offsetParent) && parent != document);
+ parent = parent.offsetParent;
+ }
return offset;
}
\ No newline at end of file | compute scroll offsets in a cross-browser way | gameclosure_js.io | train | js |
88c501300839e39eb8b747a193efbdbfd4dda5c8 | diff --git a/leveldb/db.go b/leveldb/db.go
index <HASH>..<HASH> 100644
--- a/leveldb/db.go
+++ b/leveldb/db.go
@@ -116,6 +116,7 @@ func openDB(s *session) (*DB, error) {
db.closeWg.Add(2)
go db.compaction()
go db.writeJournal()
+ db.wakeCompaction(0)
s.logf("db@open done T·%v", time.Since(start)) | leveldb: Wake compaction goroutine when opening database | syndtr_goleveldb | train | go |
57bd54c815172bf668b7cf2fd40c30ae5af9d9de | diff --git a/spec/functional/shell_spec.rb b/spec/functional/shell_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/functional/shell_spec.rb
+++ b/spec/functional/shell_spec.rb
@@ -81,7 +81,7 @@ describe Shell do
require "pty"
config = File.expand_path("shef-config.rb", CHEF_SPEC_DATA)
- reader, writer, pid = PTY.spawn("bundle exec #{ChefUtils::Dist::Infra::SHELL} --always-dump-stacktrace --no-multiline --no-singleline --no-colorize -c #{config} #{options}")
+ reader, writer, pid = PTY.spawn("bundle exec #{ChefUtils::Dist::Infra::SHELL} --no-multiline --no-singleline --no-colorize -c #{config} #{options}")
read_until(reader, "chef (#{Chef::VERSION})>")
yield reader, writer if block_given?
writer.puts('"done"') | Remove --always_dump_stacktrace from bundle exec chef-shell as it does not inherit from base class to support that option | chef_chef | train | rb |
1785b4f7c563f4e753e540a11ffe4a26606226fd | diff --git a/src/Ballybran/Core/Collections/Collection/IteratorDot.php b/src/Ballybran/Core/Collections/Collection/IteratorDot.php
index <HASH>..<HASH> 100644
--- a/src/Ballybran/Core/Collections/Collection/IteratorDot.php
+++ b/src/Ballybran/Core/Collections/Collection/IteratorDot.php
@@ -124,7 +124,7 @@ class IteratorDot implements Countable
*
* @return bool
*/
- protected function exists($array, $key)
+ private function exists($array, $key)
{
return array_key_exists($key, $array);
}
@@ -366,21 +366,6 @@ class IteratorDot implements Countable
$options = $key === null ? 0 : $key;
return json_encode($this->elements, $options);
}
- /*
- * --------------------------------------------------------------
- * ArrayAccess interface
- * --------------------------------------------------------------
- */
- /**
- * Check if a given key exists
- *
- * @param int|string $key
- * @return bool
- */
- public function offsetExists($key)
- {
- return $this->has($key);
- }
/*
* -------------------------------------------------------------- | Update IteratorDot.php | knut7_framework | train | php |
92c0414481301dcccb50691ad97cf24f45e8e76e | diff --git a/src/Commands/Install.php b/src/Commands/Install.php
index <HASH>..<HASH> 100644
--- a/src/Commands/Install.php
+++ b/src/Commands/Install.php
@@ -5,6 +5,7 @@ namespace TypiCMS\Modules\Core\Commands;
use Exception;
use Illuminate\Console\Command;
use Illuminate\Filesystem\Filesystem;
+use Illuminate\Support\Facades\Hash;
use TypiCMS\Modules\Users\Models\User;
class Install extends Command
@@ -131,7 +132,7 @@ class Install extends Command
'email' => $email,
'superuser' => 1,
'activated' => 1,
- 'password' => bcrypt($password),
+ 'password' => Hash::make($password),
];
try { | bcrypt replaced by Hash::make | TypiCMS_Core | train | php |
8f480338081a65db4314aa7d37a79c173b2262c3 | diff --git a/pybar/run_manager.py b/pybar/run_manager.py
index <HASH>..<HASH> 100644
--- a/pybar/run_manager.py
+++ b/pybar/run_manager.py
@@ -192,7 +192,7 @@ class RunBase():
log_status = logging.WARNING
else:
log_status = logging.ERROR
- logging.log(log_status, 'Stopped run #%d (%s) in %s. STATUS: %s' % (self.run_number, self.__class__.__name__, self.working_dir, self.run_status))
+ logging.log(log_status, 'Finished run #%d (%s) in %s. STATUS: %s' % (self.run_number, self.__class__.__name__, self.working_dir, self.run_status))
def stop(self, msg=None):
"""Stopping a run. Control for loops. | MAINT: avoid confision about run status | SiLab-Bonn_pyBAR | train | py |
66005fe3d9f538bbf19607a73a91434cee3af9e9 | diff --git a/interp/interp.go b/interp/interp.go
index <HASH>..<HASH> 100644
--- a/interp/interp.go
+++ b/interp/interp.go
@@ -324,7 +324,6 @@ func (r *Runner) redir(rd *syntax.Redirect) io.Closer {
return nil
case syntax.DplIn:
panic(fmt.Sprintf("unhandled redirect op: %v", rd.Op))
- return nil
}
mode := os.O_RDONLY
switch rd.Op {
@@ -609,6 +608,7 @@ func (r *Runner) arithm(expr syntax.ArithmExpr) int {
b2, ok := x.Y.(*syntax.BinaryArithm)
if !ok || b2.Op != syntax.Colon {
// TODO: error
+ return 0
}
if cond == 1 {
return r.arithm(b2.X) | interp: fix a couple of linter issues | mvdan_sh | train | go |
dd129944d330db7459ac5eeced420b5102c0378d | diff --git a/src/cache.js b/src/cache.js
index <HASH>..<HASH> 100644
--- a/src/cache.js
+++ b/src/cache.js
@@ -37,7 +37,7 @@ class HBaseThriftClientCache extends Cache {
super.get(getObj)
.then(value =>{
- callback(null, Promise.resolve(value));
+ callback(null, value);
})
.catch(err => callback(err));
} | fix cache - chace shouldn't return a promise | exposebox_node-thrift2-hbase | train | js |
447f0f73aab2d81bd7f407219c86b6801a45c884 | diff --git a/src/SmartlabelManager.js b/src/SmartlabelManager.js
index <HASH>..<HASH> 100644
--- a/src/SmartlabelManager.js
+++ b/src/SmartlabelManager.js
@@ -723,9 +723,10 @@ SmartLabelManager.prototype.getSmartText = function (text, maxWidth, maxHeight,
i = 0;
len = characterArr.length;
- minWidth = characterArr[0].elem.offsetWidth;
+ // if character array is not generated
+ minWidth = len && characterArr[0].elem.offsetWidth;
- if (minWidth > maxWidth) {
+ if (minWidth > maxWidth || !len) {
smartLabel.text = '';
smartLabel.width = smartLabel.oriTextWidth = smartLabel.height = smartLabel.oriTextHeight = 0; | added check if no characters are present in array | fusioncharts_fusioncharts-smartlabel | train | js |
8268e1519f385558241a20cf81b97225c042768e | diff --git a/mopidy_spotify/translator.py b/mopidy_spotify/translator.py
index <HASH>..<HASH> 100644
--- a/mopidy_spotify/translator.py
+++ b/mopidy_spotify/translator.py
@@ -58,7 +58,7 @@ def to_album(sp_album):
if not sp_album.is_loaded:
return
- if sp_album.artist is not None:
+ if sp_album.artist is not None and sp_album.artist.is_loaded:
artists = [to_artist(sp_album.artist)]
else:
artists = []
@@ -171,7 +171,7 @@ def to_playlist(
tracks = filter(None, tracks)
if name is None:
# Use same starred order as the Spotify client
- tracks = reversed(tracks)
+ tracks = list(reversed(tracks))
if name is None:
name = 'Starred' | tests: Fix test errors catched by model validation | mopidy_mopidy-spotify | train | py |
e0f77dabf666eee5e95c66125f65c6e84eeb6160 | diff --git a/src/socket.js b/src/socket.js
index <HASH>..<HASH> 100644
--- a/src/socket.js
+++ b/src/socket.js
@@ -81,7 +81,7 @@ function createSocket(apiClient) {
var defer = Q.defer();
realtimeSessionPromise = defer.promise;
var url = apiClient.url("/messaging/realtime/sessions", {}, {unique: (Math.random() * Date.now()).toString(16)});
- apiClient.request("post", url)
+ apiClient.request("post", url, {})
.then(function(response) {
realtimeSessionId = response.realtimeSessionId;
defer.resolve(); | Don't send empty POST, it triggers bug in react-native on Android. | Appstax_appstax-js | train | js |
bdd575fcb312c1ea0335079bc7b270961dfb4782 | diff --git a/openquake/calculators/classical.py b/openquake/calculators/classical.py
index <HASH>..<HASH> 100644
--- a/openquake/calculators/classical.py
+++ b/openquake/calculators/classical.py
@@ -371,7 +371,7 @@ class ClassicalCalculator(base.HazardCalculator):
md = '%s->%d ... %s->%d' % (it[0] + it[-1])
else:
md = oq.maximum_distance(sg.trt)
- logging.info('max_dist={}, gsims={}, weight={:,d}, blocks={}'.
+ logging.info('max_dist={}, gsims={}, weight={:_d}, blocks={}'.
format(md, len(gsims), int(w), nb))
if oq.pointsource_distance['default']:
psd = getdefault(oq.pointsource_distance, sg.trt) | Better logging [skip CI] | gem_oq-engine | train | py |
f7fbe513d764f2306afce611cda24861bf65843d | diff --git a/addon/not-equal.js b/addon/not-equal.js
index <HASH>..<HASH> 100644
--- a/addon/not-equal.js
+++ b/addon/not-equal.js
@@ -1,7 +1,5 @@
-import curriedComputed from 'ember-macro-helpers/curried-computed';
+import { not, eq } from '.';
-export default curriedComputed((firstVal, ...values) => {
- return values.filter(value => {
- return value !== firstVal;
- }).length > 0;
-});
+export default function() {
+ return not(eq(...arguments));
+} | use not and equal as the base for notEqual | kellyselden_ember-awesome-macros | train | js |
4f671cdd37414e73f2e967686d5e9332042e37a7 | diff --git a/src/google/googlefontapi.js b/src/google/googlefontapi.js
index <HASH>..<HASH> 100644
--- a/src/google/googlefontapi.js
+++ b/src/google/googlefontapi.js
@@ -11,9 +11,19 @@ webfont.GoogleFontApi.NAME = 'google';
webfont.GoogleFontApi.prototype.supportUserAgent = function(userAgent, support) {
if (userAgent.getPlatform().match(/iPad|iPod|iPhone/) != null) {
- support(false);
+ support(true);
+ return;
}
- return support(userAgent.isSupportingWebFont());
+ if (userAgent.getPlatform().match(/Android/) != null) {
+ if (userAgent.getVersion().indexOf('2.2') != -1) {
+ support(true);
+ return;
+ } else {
+ support(false);
+ return;
+ }
+ }
+ support(userAgent.isSupportingWebFont());
};
webfont.GoogleFontApi.prototype.load = function(onReady) { | Added support for iPhone, iPod, iPad. | typekit_webfontloader | train | js |
64f80645ab94c101c49c41fdd0e317d3a04cfec8 | diff --git a/src/CatalogBundle/Model/Repository/CatalogRepository.php b/src/CatalogBundle/Model/Repository/CatalogRepository.php
index <HASH>..<HASH> 100644
--- a/src/CatalogBundle/Model/Repository/CatalogRepository.php
+++ b/src/CatalogBundle/Model/Repository/CatalogRepository.php
@@ -69,7 +69,7 @@ class CatalogRepository extends Repository
$client = $this->getClient();
$cacheKey = static::NAME . '-' . $id . '-' . $locale;
- $productRequest = RequestBuilder::of()->products()->getById($id);
+ $productRequest = RequestBuilder::of()->productProjections()->getById($id);
$product = $this->retrieve($client, $cacheKey, $productRequest, $locale); | WIP: catalog_bundle fix RequestBuilder to get ProductProjections instead of Products by id | commercetools_commercetools-php-symfony | train | php |
906348dd30ffb9568905f362175ad0dd3f5da4cc | diff --git a/sources/scalac/transformer/ExpandMixinsPhase.java b/sources/scalac/transformer/ExpandMixinsPhase.java
index <HASH>..<HASH> 100644
--- a/sources/scalac/transformer/ExpandMixinsPhase.java
+++ b/sources/scalac/transformer/ExpandMixinsPhase.java
@@ -415,6 +415,14 @@ public class ExpandMixinsPhase extends Phase {
case TypeRef(Type prefix, Symbol symbol, Type[] args):
Type inline = (Type)inlines.get(symbol);
if (inline != null) return inline;
+ if (symbol.isParameter()) {
+ Symbol clone = (Symbol)cloner.clones.get(symbol);
+ if (clone != null) {
+ assert prefix == Type.NoPrefix && args.length == 0:
+ type;
+ return Type.typeRef(prefix, clone, args);
+ }
+ }
return map(type);
case SingleType(Type prefix, Symbol symbol):
Symbol clone = (Symbol)cloner.clones.get(symbol); | - Added a missing substitution for cloned type ...
- Added a missing substitution for cloned type parameters | scala_scala | train | java |
7250ec97acd6661cf3f464416cc484fe1c3a743c | diff --git a/lib/esp/resources/resource.rb b/lib/esp/resources/resource.rb
index <HASH>..<HASH> 100644
--- a/lib/esp/resources/resource.rb
+++ b/lib/esp/resources/resource.rb
@@ -22,7 +22,6 @@ module ESP
end
def self.where(clauses = {})
- puts "@@@@@@@@@ #{__FILE__}:#{__LINE__} \n********** clauses = " + clauses.inspect
fail ArgumentError, "expected a clauses Hash, got #{clauses.inspect}" unless clauses.is_a? Hash
from = clauses.delete(:from) || "#{prefix}#{name.demodulize.pluralize.underscore}"
clauses = { params: clauses }
@@ -34,7 +33,6 @@ module ESP
end
def self.find(*arguments)
- puts "@@@@@@@@@ #{__FILE__}:#{__LINE__} \n********** arguments = " + arguments.inspect
scope = arguments.slice!(0)
options = (arguments.slice!(0) || {}).with_indifferent_access
arrange_options(options)
@@ -65,7 +63,6 @@ module ESP
# Need to set from so paginated collection can use it for page calls.
object.tap do |collection|
collection.from = options['from']
- puts "@@@@@@@@@ #{__FILE__}:#{__LINE__} \n********** options = " + options.inspect
collection.original_params = options['params']
end
end | Didn't mean to commit that. | EvidentSecurity_esp_sdk | train | rb |
9efadd01338990b019a45abbff14e3432defa664 | diff --git a/src/org/opencms/xml/containerpage/CmsXmlContainerPage.java b/src/org/opencms/xml/containerpage/CmsXmlContainerPage.java
index <HASH>..<HASH> 100644
--- a/src/org/opencms/xml/containerpage/CmsXmlContainerPage.java
+++ b/src/org/opencms/xml/containerpage/CmsXmlContainerPage.java
@@ -955,8 +955,12 @@ public class CmsXmlContainerPage extends CmsXmlContent {
I_CmsFormatterBean formatter = null;
if (formatterKey != null) {
Element formatterKeyElem = elemElement.addElement(XmlNode.FormatterKey.name());
- formatterKeyElem.addText(formatterKey);
+
formatter = adeConfig.findFormatter(formatterKey);
+ if ((formatter != null) && (formatter.getKeyOrId() != null)) {
+ formatterKey = formatter.getKeyOrId();
+ }
+ formatterKeyElem.addText(formatterKey);
}
CmsResource elementRes; | Fixed problem with formatter id not being rewritten to formatter key in new container page format. | alkacon_opencms-core | train | java |
3e6ca5e976de219fc444c7871c6f22da1c45b7af | diff --git a/mythril/ether/ethcontract.py b/mythril/ether/ethcontract.py
index <HASH>..<HASH> 100644
--- a/mythril/ether/ethcontract.py
+++ b/mythril/ether/ethcontract.py
@@ -12,8 +12,8 @@ class ETHContract(persistent.Persistent):
# Dynamic contract addresses of the format __[contract-name]_____________ are replaced with a generic address
# Apply this for creation_code & code
- creation_code = re.sub(r'(_+.*_+)', 'aa' * 20, creation_code)
- code = re.sub(r'(_+.*_+)', 'aa' * 20, code)
+ creation_code = re.sub(r'(_{2}.{38})', 'aa' * 20, creation_code)
+ code = re.sub(r'(_{2}.{38})', 'aa' * 20, code)
self.creation_code = creation_code
self.name = name | Chnage regex to limit to correct pattern | ConsenSys_mythril-classic | train | py |
9d23e05691e3d9f1632e6498698a5b4c40b416b9 | diff --git a/lib/clean.js b/lib/clean.js
index <HASH>..<HASH> 100644
--- a/lib/clean.js
+++ b/lib/clean.js
@@ -9,7 +9,7 @@ exports.usage = 'Removes any generated build files and the "out" dir'
var rm = require('rimraf')
, glob = require('glob')
- , targets = [ 'out' ]
+ , targets = []
/**
* Add the platform-specific targets to remove.
@@ -17,10 +17,13 @@ var rm = require('rimraf')
if (process.platform == 'win32') {
// Remove MSVC project files
+ targets.push('Debug')
+ targets.push('Release')
targets.push('*.sln')
targets.push('*.vcxproj*')
} else {
// Remove Makefile project files
+ targets.push('out')
targets.push('Makefile')
targets.push('*.Makefile')
targets.push('*.target.mk') | Clean the Debug and Release dirs on Windows. | CodeJockey_node-ninja | train | js |
46fb0f84d68a6cd0b314e27f72494def9d92f9d8 | diff --git a/core/src/main/java/hudson/matrix/Axis.java b/core/src/main/java/hudson/matrix/Axis.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/hudson/matrix/Axis.java
+++ b/core/src/main/java/hudson/matrix/Axis.java
@@ -197,12 +197,16 @@ public class Axis extends AbstractDescribableImpl<Axis> implements Comparable<Ax
public Object readResolve() {
if (getClass()!=Axis.class) return this;
+ /*
+ This method is necessary only because earlier versions of Jenkins treated
+ axis names "label" and "jdk" differently,
+ plus Axis was a concrete class, and we need to be able to read that back.
+ So this measure is not needed for newly added Axes.
+ */
if (getName().equals("jdk"))
return new JDKAxis(getValues());
if (getName().equals("label"))
return new LabelAxis(getName(),getValues());
- if (getName().equals("labelExp"))
- return new LabelExpAxis(getName(),getValues());
return new TextAxis(getName(),getValues());
} | this method is necessary only because earlier versions of Jenkins treated axis names "label" and "jdk" differently and we need to be able to read that back.
So this measure is not needed for newly added Axes. | jenkinsci_jenkins | train | java |
3db3667024ceb940e4bd66e82f2dcaa3ba671484 | diff --git a/sdk/tables/azure-data-tables/tests/test_table_client_cosmos.py b/sdk/tables/azure-data-tables/tests/test_table_client_cosmos.py
index <HASH>..<HASH> 100644
--- a/sdk/tables/azure-data-tables/tests/test_table_client_cosmos.py
+++ b/sdk/tables/azure-data-tables/tests/test_table_client_cosmos.py
@@ -6,10 +6,10 @@
import pytest
import platform
from time import sleep
+import sys
from azure.data.tables import TableServiceClient, TableClient
from azure.data.tables._version import VERSION
-from azure.core.exceptions import HttpResponseError
from _shared.testcase import (
TableTestCase,
@@ -419,7 +419,7 @@ class StorageTableClientTest(TableTestCase):
if self.is_live:
sleep(SLEEP_DELAY)
- @pytest.mark.xfail
+ @pytest.mark.skipif(sys.version_info < (3, 0), reason="Malformed string")
@CosmosPreparer()
def test_user_agent_default(self, tables_cosmos_account_name, tables_primary_cosmos_account_key):
service = TableServiceClient(self.account_url(tables_cosmos_account_name, "cosmos"), credential=tables_primary_cosmos_account_key) | added python3 conditional (#<I>)
addresses #<I> | Azure_azure-sdk-for-python | train | py |
84ecbba8d2d7c48459cc0b674dc49ef9d5cc4942 | diff --git a/termgraph/termgraph.py b/termgraph/termgraph.py
index <HASH>..<HASH> 100755
--- a/termgraph/termgraph.py
+++ b/termgraph/termgraph.py
@@ -144,7 +144,7 @@ def main():
print('termgraph v{}'.format(VERSION))
sys.exit()
- labels, data, colors = read_data(args)
+ _, labels, data, colors = read_data(args)
if args['calendar']:
calendar_heatmap(data, labels, args)
else: | Fix for unbalanced args | mkaz_termgraph | train | py |
957bedefb831672fc7cd70bf76bebf611cf52e9f | diff --git a/example/github_server.js b/example/github_server.js
index <HASH>..<HASH> 100644
--- a/example/github_server.js
+++ b/example/github_server.js
@@ -12,7 +12,7 @@ server.connection({
var opts = {
REDIRECT_URL: '/githubauth', // must match google app redirect URI
handler: require('./github_oauth_handler.js'), // your handler
- scope: 'user' // get user's profile see: developer.github.com/v3/oauth/#scopes
+ SCOPE: 'user' // get user's profile see: developer.github.com/v3/oauth/#scopes
};
var hapi_auth_github = require('../lib');
diff --git a/lib/index.js b/lib/index.js
index <HASH>..<HASH> 100644
--- a/lib/index.js
+++ b/lib/index.js
@@ -97,7 +97,7 @@ module.exports.login_url = function() {
var params = {
client_id : process.env.GITHUB_CLIENT_ID,
redirect_uri : process.env.BASE_URL + OPTIONS.REDIRECT_URL,
- scope : 'repo',
+ scope : OPTIONS.SCOPE,
state: crypto.createHash('sha256').update(Math.random().toString()).digest('hex')
}
console.log(params); | scope for auth is defined when registering the plugin. fixes #4 | dwyl_hapi-auth-github | train | js,js |
5a493c0adfc725ca9b4a835fca87076b73951cd5 | diff --git a/Swat/SwatUI.php b/Swat/SwatUI.php
index <HASH>..<HASH> 100644
--- a/Swat/SwatUI.php
+++ b/Swat/SwatUI.php
@@ -174,9 +174,9 @@ class SwatUI extends SwatObject {
case 'boolean':
return ($value == 'true') ? true : false;
case 'integer':
- return intval(substr($value, 8));
+ return intval($value);
case 'float':
- return floatval(substr($value, 6));
+ return floatval($value);
case 'string':
return $this->translateValue($value, $translatable);
case 'data': | Fixed bug with SwatUI's handling of integer and float values for properties
svn commit r<I> | silverorange_swat | train | php |
80d84e99f1558d79c348d8db03ff7b78a1afe3f8 | diff --git a/src/Forms/FormData.php b/src/Forms/FormData.php
index <HASH>..<HASH> 100644
--- a/src/Forms/FormData.php
+++ b/src/Forms/FormData.php
@@ -46,6 +46,20 @@ class FormData
}
/**
+ * @return array
+ */
+ public function getAllMessages()
+ {
+ $allMessages = [ ];
+ foreach ( $this->feedbacks as $feedback )
+ {
+ $allMessages = array_merge( $allMessages, $feedback->getMessages() );
+ }
+
+ return $allMessages;
+ }
+
+ /**
* @param string $key
*
* @return bool | Added getAllMessages to FormData | fortuneglobe_icehawk | train | php |
77c5c6a1b6176071f3d69f29a1ec714141c09d02 | diff --git a/src/check.js b/src/check.js
index <HASH>..<HASH> 100644
--- a/src/check.js
+++ b/src/check.js
@@ -9,7 +9,8 @@ const lintedByEslintPrettier = {
const eslintConfig = (info.pkg && info.pkg.eslintConfig) || info.eslintrc
assert(
eslintConfig &&
- eslintConfig.extends.indexOf('eslint-config-cozy-app') > -1,
+ // eslint-config- can be ommitted
+ ['eslint-config-cozy-app', 'cozy-app'].includes(eslintConfig.extends),
'eslintConfig should extend from prettier'
)
}, | 📝 feat: accept also 'cozy-app' for eslint preset | konnectors_konitor | train | js |
715f1d096cc0d788d4850edab6e296eed6c70b3d | diff --git a/lib/dragonfly/extended_temp_object.rb b/lib/dragonfly/extended_temp_object.rb
index <HASH>..<HASH> 100644
--- a/lib/dragonfly/extended_temp_object.rb
+++ b/lib/dragonfly/extended_temp_object.rb
@@ -87,9 +87,8 @@ module Dragonfly
def method_missing(method, *args, &block)
if analyser.has_delegatable_method?(method)
- # Define the method so we don't use method_missing next time
- instance_var = "@#{method}"
- self.class.class_eval do
+ # Define the method on the instance so we don't use method_missing next time
+ class << self; self; end.class_eval do
define_method method do
cache[method] ||= analyser.delegate(method, self)
end | Oops was defining a method on the class rather than the instance of extended_temp_object (was breaking specs elsewhere) | markevans_dragonfly | train | rb |
924026b09aa56f4d407c87346925449120af72f6 | diff --git a/implementations/micrometer-registry-statsd/src/main/java/io/micrometer/statsd/StatsdGauge.java b/implementations/micrometer-registry-statsd/src/main/java/io/micrometer/statsd/StatsdGauge.java
index <HASH>..<HASH> 100644
--- a/implementations/micrometer-registry-statsd/src/main/java/io/micrometer/statsd/StatsdGauge.java
+++ b/implementations/micrometer-registry-statsd/src/main/java/io/micrometer/statsd/StatsdGauge.java
@@ -47,12 +47,15 @@ public class StatsdGauge<T> extends AbstractMeter implements Gauge, StatsdPollab
@Override
public double value() {
T obj = ref.get();
- return obj != null ? value.applyAsDouble(ref.get()) : 0;
+ return obj != null ? value.applyAsDouble(ref.get()) : Double.NaN;
}
@Override
public void poll() {
double val = value();
+ if (val == Double.NaN) {
+ val = 0;
+ }
if (!shutdown && (alwaysPublish || lastValue.getAndSet(val) != val)) {
subscriber.onNext(lineBuilder.gauge(val));
} | StatsdGauge#value returns NaN but still outputs 0 lines | micrometer-metrics_micrometer | train | java |
fbf970d0b9cd2ce092ec25c4d4733f1d61d6ebd4 | diff --git a/lib/feed2email/database.rb b/lib/feed2email/database.rb
index <HASH>..<HASH> 100644
--- a/lib/feed2email/database.rb
+++ b/lib/feed2email/database.rb
@@ -11,11 +11,18 @@ module Feed2Email
private
- def setup_connection(options)
- @connection = Sequel.connect(options)
+ def create_entries_table
+ connection.create_table? :entries do
+ primary_key :id
+ foreign_key :feed_id, :feeds, null: false, index: true,
+ on_delete: :cascade
+ String :uri, null: false, unique: true
+ Time :created_at
+ Time :updated_at
+ end
end
- def setup_schema
+ def create_feeds_table
connection.create_table? :feeds do
primary_key :id
String :uri, null: false, unique: true
@@ -27,15 +34,15 @@ module Feed2Email
Time :created_at
Time :updated_at
end
+ end
- connection.create_table? :entries do
- primary_key :id
- foreign_key :feed_id, :feeds, null: false, index: true,
- on_delete: :cascade
- String :uri, null: false, unique: true
- Time :created_at
- Time :updated_at
- end
+ def setup_connection(options)
+ @connection = Sequel.connect(options)
+ end
+
+ def setup_schema
+ create_feeds_table
+ create_entries_table
end
end
end | Create each table in a separate method
SRP | agorf_feed2email | train | rb |
032ea87785951314f5f0575e7ff734dd39ad7689 | diff --git a/lib/poolparty/net/remoter/connections.rb b/lib/poolparty/net/remoter/connections.rb
index <HASH>..<HASH> 100644
--- a/lib/poolparty/net/remoter/connections.rb
+++ b/lib/poolparty/net/remoter/connections.rb
@@ -69,7 +69,7 @@ module PoolParty
:timeout => 3.minutes,
:user => user
}.merge(opts)
- ssh_options_hash[:verbose]=:debug if debugging?
+ # ssh_options_hash[:verbose]=:debug if debugging?
puts "connecting to ssh with options = #{ssh_options_hash.inspect}"
Net::SSH.start(host, user, ssh_options_hash) do |ssh|
cmds.each do |command| | rm'd ssh debugging from debug output. this data is not particularly helpful and it makes it really tricky to read | auser_poolparty | train | rb |
5181b8a41e960efbfd327ba10db39ed4120c2a25 | diff --git a/Classes/Hooks/DrawItem.php b/Classes/Hooks/DrawItem.php
index <HASH>..<HASH> 100644
--- a/Classes/Hooks/DrawItem.php
+++ b/Classes/Hooks/DrawItem.php
@@ -896,7 +896,7 @@ class DrawItem implements PageLayoutViewDrawItemHookInterface, SingletonInterfac
{
$specificIds = $this->helper->getSpecificIds($row);
$grid = '<div class="t3-grid-container t3-grid-element-container' . ($layout['frame'] ? ' t3-grid-container-framed t3-grid-container-' . htmlspecialchars($layout['frame']) : '') . ($layout['top_level_layout'] ? ' t3-grid-tl-container' : '') . '">';
- if ($layout['frame'] || $this->helper->getBackendUser()->uc['showGridInformation'] === 1) {
+ if ($layout['frame'] || (int)$this->helper->getBackendUser()->uc['showGridInformation'] === 1) {
$grid .= '<h4 class="t3-grid-container-title-' . htmlspecialchars($layout['frame']) . '">' .
BackendUtility::wrapInHelp(
'tx_gridelements_backend_layouts', | [BUGFIX] Make sure values are integers for strict comparison
Change-Id: Ic<I>a<I>a<I>ce<I>d<I>a<I>d<I>de<I>e
Resolves: #<I>
Release: master, 8-0
Reviewed-on: <URL> | TYPO3-extensions_gridelements | train | php |
8c2b9cc7cfa2f7389641b7a894112f05c61f2876 | diff --git a/lib/hanami/slice.rb b/lib/hanami/slice.rb
index <HASH>..<HASH> 100644
--- a/lib/hanami/slice.rb
+++ b/lib/hanami/slice.rb
@@ -18,6 +18,14 @@ module Hanami
@container = container || define_container
end
+ def inflector
+ application.inflector
+ end
+
+ def namespace_path
+ @namespace_path ||= inflector.underscore(namespace.to_s)
+ end
+
def init
container.import application: application.container
@@ -113,13 +121,5 @@ module Hanami
container
end
# rubocop:enable Metrics/AbcSize, Metrics/MethodLength
-
- def namespace_path
- @namespace_path ||= inflector.underscore(namespace.to_s)
- end
-
- def inflector
- application.inflector
- end
end
end | Make a couple of slice methods public
We're using this for the work-in-progress hanami-view integration | hanami_hanami | train | rb |
8ddc567a88aa0d4a18ded4fd6c85309d1d2ed563 | diff --git a/mongostore/main.go b/mongostore/main.go
index <HASH>..<HASH> 100644
--- a/mongostore/main.go
+++ b/mongostore/main.go
@@ -7,8 +7,8 @@ import (
nSessions "github.com/goincremental/negroni-sessions"
"github.com/gorilla/securecookie"
gSessions "github.com/gorilla/sessions"
- "labix.org/v2/mgo"
- "labix.org/v2/mgo/bson"
+ "gopkg.in/mgo.v2"
+ "gopkg.in/mgo.v2/bson"
)
// New returns a new mongo store | Changed mgo import path to recommended one | GoIncremental_negroni-sessions | train | go |
067abc1068c295280f373852ebe69026e65655e1 | diff --git a/src/Connection/Connection.php b/src/Connection/Connection.php
index <HASH>..<HASH> 100644
--- a/src/Connection/Connection.php
+++ b/src/Connection/Connection.php
@@ -116,7 +116,7 @@ class Connection implements ConnectionInterface
$response = $this->getResponse();
- if ($command->isMultiLine()) {
+ if ($command->isMultiLine() && ($response->getStatusCode() >= 200 && $response->getStatusCode() <= 399)) {
$response = $command->isCompressed() ? $this->getCompressedResponse($response) : $this->getMultiLineResponse($response);
} | Multiline response only on success
Only process a multiline response when the command was successful.
Without this certain commands hang while waiting for a multiline
response that never comes such as a BODY command that returns a <I> or
an XOVER command without selecting a group first (<I>). | robinvdvleuten_php-nntp | train | php |
9e45ff3cb600241f0a2e14fb6eb95935e5d869ea | diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -500,10 +500,7 @@ Pagelet.readable('connect', function connect(spark, next) {
return pagelet;
}
- if ('function' !== this.authorize) return substream(true);
- this.authorize(spark.request, substream);
-
- return this;
+ return this.authenticate(spark.request, substream);
});
/** | [major][security] Pagelet was not authenticated when a real-time connection was used. | bigpipe_pagelet | train | js |
89faa7e9c481a83ddba0f615a805dc01a1a05f45 | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -9,6 +9,7 @@ setup(
packages=[
'two_factor',
],
+ package_data={'two_factor': ['templates/two_factor/*.html',],},
url='http://github.com/Bouke/django-two-factor-auth',
description='Complete Two-Factor Authentication for Django',
license='MIT', | Include templates in package_data, so they will be installed | Bouke_django-two-factor-auth | train | py |
4e2d19172e984245e4aad0ed7ef3f11e59153deb | diff --git a/WordPress/Sniffs/CodeAnalysis/AssignmentInConditionSniff.php b/WordPress/Sniffs/CodeAnalysis/AssignmentInConditionSniff.php
index <HASH>..<HASH> 100644
--- a/WordPress/Sniffs/CodeAnalysis/AssignmentInConditionSniff.php
+++ b/WordPress/Sniffs/CodeAnalysis/AssignmentInConditionSniff.php
@@ -193,10 +193,15 @@ class AssignmentInConditionSniff extends Sniff {
}
if ( true === $hasVariable ) {
+ $errorCode = 'Found';
+ if ( T_WHILE === $token['code'] ) {
+ $errorCode = 'FoundInWhileCondition';
+ }
+
$this->phpcsFile->addWarning(
'Variable assignment found within a condition. Did you mean to do a comparison?',
$hasAssignment,
- 'Found'
+ $errorCode
);
} else {
$this->phpcsFile->addWarning( | AssignmentInCondition: add separate errorcode for assignment found in while
A `while()` condition is the only control structure in which it is sometimes legitimate to use an assignment in condition.
Having a separate error code will enable people to selectively exclude warnings for this. | WordPress-Coding-Standards_WordPress-Coding-Standards | train | php |
7cc34707be51a5333bcda9cedc745b79bfe08e85 | diff --git a/Script/Gt.js b/Script/Gt.js
index <HASH>..<HASH> 100644
--- a/Script/Gt.js
+++ b/Script/Gt.js
@@ -213,9 +213,6 @@ _nodeListHelpers = {
"querySelectorAll",
"qs",
"qsa",
- "removeAttribute",
- "removeAttributeNS",
- "removeAttributeNode",
"removeChild",
"replaceChild",
"scrollIntoView",
@@ -232,6 +229,9 @@ _nodeListHelpers = {
"dispatchEvent",
"normalise",
"remove",
+ "removeAttribute",
+ "removeAttributeNS",
+ "removeAttributeNode",
"removeEventListener",
"replace"
] | RemoveAttribute methods are invoked on all elements within collection. | PhpGt_WebEngine | train | js |
57286d980b384f25b3c0dfc571ef2e4837047c03 | diff --git a/lib/gds_api/test_helpers/support_api.rb b/lib/gds_api/test_helpers/support_api.rb
index <HASH>..<HASH> 100644
--- a/lib/gds_api/test_helpers/support_api.rb
+++ b/lib/gds_api/test_helpers/support_api.rb
@@ -102,6 +102,10 @@ module GdsApi
stub_http_request(:get, "#{SUPPORT_API_ENDPOINT}/anonymous-feedback/export-requests/#{id}").
to_return(status: 200, body: response_body.to_json)
end
+
+ def stub_any_support_api_call
+ stub_request(:any, %r{\A#{SUPPORT_API_ENDPOINT}})
+ end
end
end
end | Test helper to stub any call to the Support API | alphagov_gds-api-adapters | train | rb |
8dfe560df167252c4edf5cbef087f8a3c3413a84 | diff --git a/src/de/mrapp/android/validation/PasswordEditText.java b/src/de/mrapp/android/validation/PasswordEditText.java
index <HASH>..<HASH> 100644
--- a/src/de/mrapp/android/validation/PasswordEditText.java
+++ b/src/de/mrapp/android/validation/PasswordEditText.java
@@ -273,7 +273,7 @@ public class PasswordEditText extends EditText {
setHelperTextColor(helperTextColors.get(index));
}
- return -1;
+ return regularHelperTextColor;
}
/** | The default helper text color is now used, if no helper text colors are specified. | michael-rapp_AndroidMaterialValidation | train | java |
29f2ce4bebf09382173594eff0f61349eb41f979 | diff --git a/cloud4rpid.py b/cloud4rpid.py
index <HASH>..<HASH> 100644
--- a/cloud4rpid.py
+++ b/cloud4rpid.py
@@ -329,6 +329,7 @@ if __name__ == "__main__":
exit(1)
except NoSensorsError:
print('No sensors found... Exiting')
+ exit(1)
except Exception as e:
print('Unexpected error: {0}'.format(e.message))
log.exception(e) | Exit with a nonzero error code when no sensors found | cloud4rpi_cloud4rpi | train | py |
4c63b2bbd52c2e248e88329ac25d47e211f5986e | diff --git a/src/locale.js b/src/locale.js
index <HASH>..<HASH> 100644
--- a/src/locale.js
+++ b/src/locale.js
@@ -621,7 +621,7 @@ function formatUTCWeekdayNumberMonday(d) {
}
function formatUTCWeekNumberSunday(d, p) {
- return pad(utcSunday.count(utcYear(d), d), p, 2);
+ return pad(utcSunday.count(utcYear(d) - 1, d), p, 2);
}
function formatUTCWeekNumberISO(d, p) {
@@ -635,7 +635,7 @@ function formatUTCWeekdayNumberSunday(d) {
}
function formatUTCWeekNumberMonday(d, p) {
- return pad(utcMonday.count(utcYear(d), d), p, 2);
+ return pad(utcMonday.count(utcYear(d) - 1, d), p, 2);
}
function formatUTCYear(d, p) { | Fix off-by-one in utcFormat. | d3_d3-time-format | train | js |
2e69c7933c0fa99114846ccab38bbcc9bd4a5efc | diff --git a/lib/active_scaffold/helpers/association_helpers.rb b/lib/active_scaffold/helpers/association_helpers.rb
index <HASH>..<HASH> 100644
--- a/lib/active_scaffold/helpers/association_helpers.rb
+++ b/lib/active_scaffold/helpers/association_helpers.rb
@@ -15,10 +15,7 @@ module ActiveScaffold
# Provides a way to honor the :conditions on an association while searching the association's klass
def association_options_find(association, conditions = nil, klass = nil, record = nil)
if klass.nil? && association.polymorphic?
- class_name = case association.macro
- when :belongs_to then record.send(association.foreign_type)
- when :belongs_to_record, :belongs_to_document then record.send(association.type)
- end
+ class_name = record.send(association.foreign_type) if association.belongs_to?
if class_name.present?
klass = class_name.constantize
else | fix usage of Association class to get foreign_type on polymorphic | activescaffold_active_scaffold | train | rb |
97beb006a1307a770d9cde60ca7eea725e99e70c | diff --git a/src/Illuminate/Console/Scheduling/ScheduleTestCommand.php b/src/Illuminate/Console/Scheduling/ScheduleTestCommand.php
index <HASH>..<HASH> 100644
--- a/src/Illuminate/Console/Scheduling/ScheduleTestCommand.php
+++ b/src/Illuminate/Console/Scheduling/ScheduleTestCommand.php
@@ -33,7 +33,7 @@ class ScheduleTestCommand extends Command
$commandNames = [];
foreach ($commands as $command) {
- $commandNames[] = $command->command;
+ $commandNames[] = $command->command ?? $command->getSummaryForDisplay();
}
$index = array_search($this->choice('Which command would you like to run?', $commandNames), $commandNames); | Fix running schedule test on CallbackEvents (#<I>) | laravel_framework | train | php |
029762db49e4f42012f3390ad64a6b53e34225cb | diff --git a/koala/Range.py b/koala/Range.py
index <HASH>..<HASH> 100644
--- a/koala/Range.py
+++ b/koala/Range.py
@@ -539,7 +539,12 @@ class RangeCore(dict):
@staticmethod
def add(a, b):
try:
- return check_value(a) + check_value(b)
+ a = check_value(a)
+ b = check_value(b)
+ if isinstance(a, str) or isinstance(b, str):
+ a = str(a)
+ b = str(b)
+ return a + b
except Exception as e:
return ExcelError('#N/A', e) | Add strings
If one of the two values would be a string like in the formula "'<='&<I>", this would crash since Python cannot add int + str. If this is the case, parse them both as strings. | anthill_koala | train | py |
0055d476d90fbf1ee8175585f4f532e784bfd750 | diff --git a/multiqc/modules/ngsderive/ngsderive.py b/multiqc/modules/ngsderive/ngsderive.py
index <HASH>..<HASH> 100644
--- a/multiqc/modules/ngsderive/ngsderive.py
+++ b/multiqc/modules/ngsderive/ngsderive.py
@@ -264,6 +264,9 @@ class MultiqcModule(BaseMultiqcModule):
headers["majoritypctdetected"] = {
"title": "Read Length: % Supporting",
"description": "Percentage of reads which were measured at the predicted read length.",
+ "min": 0,
+ "max": 100,
+ "suffix": "%",
}
self.general_stats_addcols(data, headers) | refactor: add percentage suffix to read length % | ewels_MultiQC | train | py |
fa84b1f3dfa424e1831f47fb2723baaa547e8740 | diff --git a/Listener/TaggedEntityListener.php b/Listener/TaggedEntityListener.php
index <HASH>..<HASH> 100644
--- a/spec/circleci/cli/command/base_command_spec.rb
+++ b/spec/circleci/cli/command/base_command_spec.rb
@@ -29,7 +29,24 @@ describe CircleCI::CLI::Command::BaseCommand do
end
describe '.branch_name' do
- subject { described_class.branch_name(OpenStruct.new) }
+ subject { described_class.branch_name(options) }
+ let(:options) { OpenStruct.new }
+
+ context 'with all option' do
+ let(:options) { OpenStruct.new(all: true) }
+ let(:rugged_response_branch_name) { 'branch' }
+ let(:rugged_response_is_branch) { true }
+
+ it { is_expected.to eq(nil) }
+ end
+
+ context 'with branch option' do
+ let(:options) { OpenStruct.new(branch: 'optionBranch') }
+ let(:rugged_response_branch_name) { 'branch' }
+ let(:rugged_response_is_branch) { true }
+
+ it { is_expected.to eq('optionBranch') }
+ end
context 'with a valid current branch' do
let(:rugged_response_branch_name) { 'branch' } | :green_heart: Update specs | unhappychoice_Circler | train | rb |
fadcdbc5aee449e1d3f8b80a7a183293914a90fe | diff --git a/Classes/RobertLemke/Plugin/Blog/Controller/CommentController.php b/Classes/RobertLemke/Plugin/Blog/Controller/CommentController.php
index <HASH>..<HASH> 100644
--- a/Classes/RobertLemke/Plugin/Blog/Controller/CommentController.php
+++ b/Classes/RobertLemke/Plugin/Blog/Controller/CommentController.php
@@ -61,6 +61,10 @@ class CommentController extends ActionController
$this->throwStatus(400, 'Your comment was NOT created - it was too short.');
}
+ $newComment->setProperty('text', filter_var($newComment->getProperty('text'), FILTER_SANITIZE_STRIPPED));
+ $newComment->setProperty('author', filter_var($newComment->getProperty('author'), FILTER_SANITIZE_STRIPPED));
+ $newComment->setProperty('emailAddress', filter_var($newComment->getProperty('emailAddress'), FILTER_SANITIZE_STRIPPED));
+
$commentNode = $postNode->getNode('comments')->createNodeFromTemplate($newComment, uniqid('comment-'));
$commentNode->setProperty('spam', false);
$commentNode->setProperty('datePublished', new \DateTime()); | BUGFIX: Fixes an XSS issue in the comment form
This fixes an issue with the comment form which accepts unvalidated
user input and can result in XSS exploitations.
Resolves #<I> | robertlemke_RobertLemke.Plugin.Blog | train | php |
b8553c380f3711f437420fa58f502cc40ca7f5e9 | diff --git a/src/Functional/HStringWalk.php b/src/Functional/HStringWalk.php
index <HASH>..<HASH> 100644
--- a/src/Functional/HStringWalk.php
+++ b/src/Functional/HStringWalk.php
@@ -9,7 +9,7 @@ class HStringWalk
* @param HString &$hString
* @param callable $func
*/
- public static function walk(HString &$hString, callable $func)
+ public static function walk(HString $hString, callable $func)
{
$size = $hString->count(); | Remove object alias since objects are always passed by reference | ericpoe_haystack | train | php |
cb90045e2e32806df56925c77e8cfae840d4ebbb | diff --git a/tangelo/tangelo/server.py b/tangelo/tangelo/server.py
index <HASH>..<HASH> 100644
--- a/tangelo/tangelo/server.py
+++ b/tangelo/tangelo/server.py
@@ -430,6 +430,8 @@ class Tangelo(object):
tangelo.http_status(501, "Error Importing Service")
tangelo.content_type("application/json")
result = tangelo.util.traceback_report(error="Could not import module %s" % (tangelo.request_path()))
+
+ tangelo.log_warning("SERVICE", "Could not import service module %s:\n%s" % (tangelo.request_path(), "\n".join(result["traceback"])))
else:
# Try to run the service - either it's in a function called
# "run()", or else it's in a REST API consisting of at least one of | Reporting traceback when module *loading* fails, in addition to when module *execution* fails | Kitware_tangelo | train | py |
4d0850fe725ff43cb73d1f574fb452b74926cfa4 | diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -10,7 +10,7 @@ const {BrowserWindow} = electron;
var util = require('util');
var colors = require('colors');
var EventEmitter = require('events');
-var exec = require('child-process-promise').exec;
+var spawn = require('child-process-promise').spawn;
var DEFAULT_WINDOW = { width: 1024, height: 728, show: false };
var NOOP = function(){};
@@ -55,7 +55,7 @@ function electronify(cfg) {
}
// start child process
- exec(cfg.command, cfg.options)
+ spawn(cfg.command, cfg.options)
.then(function (result) {
debug('Command completed.'); | Change exec to spawn
`exec` will cause the main process to crash if there is too much data. | eliquious_electronify-server | train | js |
d49bcbfad7abff9fb48251a60b3c3ea8864a6496 | diff --git a/src/Common/ExtendedPsrLoggerWrapper.php b/src/Common/ExtendedPsrLoggerWrapper.php
index <HASH>..<HASH> 100644
--- a/src/Common/ExtendedPsrLoggerWrapper.php
+++ b/src/Common/ExtendedPsrLoggerWrapper.php
@@ -99,6 +99,7 @@ class ExtendedPsrLoggerWrapper extends AbstractLogger implements ExtendedLogger
try {
$result = call_user_func($fn, $this);
} catch(Exception $e) {
+ // Simulate try...finally
}
$this->captionTrail->removeCaption($coupon);
$this->context = $oldContext;
@@ -125,6 +126,7 @@ class ExtendedPsrLoggerWrapper extends AbstractLogger implements ExtendedLogger
try {
$result = call_user_func($fn, $this);
} catch(Exception $e) {
+ // Simulate try...finally
}
$this->logger = $previousLogger;
if($e !== null) { | - Fixed two scrutinizer inspection results: "Consider adding a comment why this CATCH block is empty." | LoggerEssentials_LoggerEssentials | train | php |
611b4fd68080685a5313b1d366dda69412cb616f | diff --git a/lib/pancakes.mongo.adapter.js b/lib/pancakes.mongo.adapter.js
index <HASH>..<HASH> 100644
--- a/lib/pancakes.mongo.adapter.js
+++ b/lib/pancakes.mongo.adapter.js
@@ -53,7 +53,10 @@ MongoAdapter.modelCache = {};
*/
MongoAdapter.connect = function connect(dbUri, debugFlag, mongos) {
var deferred = Q.defer();
- var opts = {};
+ var opts = {
+ server: { socketOptions: { keepAlive: 1, connectTimeoutMS: 30000 } },
+ replset: { socketOptions: { keepAlive: 1, connectTimeoutMS : 30000 } }
+ };
if (mongos) {
opts.mongos = true; | Adding socket options for mongo connection | gethuman_pancakes-mongo | train | js |
40896baa69125429269564055e582fab58cf5b35 | diff --git a/bigchaindb/util.py b/bigchaindb/util.py
index <HASH>..<HASH> 100644
--- a/bigchaindb/util.py
+++ b/bigchaindb/util.py
@@ -45,8 +45,10 @@ def pool(builder, size, timeout=None):
size: the size of the pool.
Returns:
- A context manager that can be used with ``with``.
+ A context manager that can be used with the ``with``
+ statement.
"""
+
lock = threading.Lock()
local_pool = queue.Queue()
current_size = 0
@@ -54,16 +56,26 @@ def pool(builder, size, timeout=None):
@contextlib.contextmanager
def pooled():
nonlocal current_size
- if current_size == size:
- instance = local_pool.get(timeout=timeout)
- else:
+ instance = None
+
+ # If we still have free slots, then we have room to create new
+ # instances.
+ if current_size < size:
with lock:
- if current_size == size:
- instance = local_pool.get(timeout=timeout)
- else:
+ # We need to check again if we have slots available, since
+ # the situation might be different after acquiring the lock
+ if current_size < size:
current_size += 1
instance = builder()
+
+ # Watchout: current_size can be equal to size if the previous part of
+ # the function has been executed, that's why we need to check if the
+ # instance is None.
+ if instance is None and current_size == size:
+ instance = local_pool.get(timeout=timeout)
+
yield instance
+
local_pool.put(instance)
return pooled | Reorganize the code for the context manager
There was probably a deadlock in the previous version. | bigchaindb_bigchaindb | train | py |
7e4495f93f781a45ed4c8c854a787d22277a4128 | diff --git a/lib/node/base.rb b/lib/node/base.rb
index <HASH>..<HASH> 100644
--- a/lib/node/base.rb
+++ b/lib/node/base.rb
@@ -12,6 +12,13 @@ module Bcome::Node
INVENTORY_KEY = "inventory"
COLLECTION_KEY = "collection"
+ def self.const_missing(constant)
+ ## Hook for direct access to node level resources by constant name where
+ ## cd ServerName should yield the same outcome as cd "ServerName"
+ set_context = ::IRB.CurrentContext.workspace.main
+ return (resource = set_context.resource_for_identifier(constant.to_s)) ? constant.to_s : super
+ end
+
def initialize(params)
@raw_view_data = params[:view_data]
@parent = params[:parent]
diff --git a/lib/node/estate.rb b/lib/node/estate.rb
index <HASH>..<HASH> 100644
--- a/lib/node/estate.rb
+++ b/lib/node/estate.rb
@@ -19,6 +19,7 @@ module Bcome::Node
def to_s
"estate"
end
+
end
def load_resources | can now cd into a resource if it would otherwise be a constance e.g. cd FooBar | webzakimbo_bcome-kontrol | train | rb,rb |
606bb2e653cbee59fc41d1bf7bd2ec3ed3272d80 | diff --git a/moa/src/main/java/moa/tasks/EvaluateMultipleClusterings.java b/moa/src/main/java/moa/tasks/EvaluateMultipleClusterings.java
index <HASH>..<HASH> 100644
--- a/moa/src/main/java/moa/tasks/EvaluateMultipleClusterings.java
+++ b/moa/src/main/java/moa/tasks/EvaluateMultipleClusterings.java
@@ -142,7 +142,7 @@ public class EvaluateMultipleClusterings extends AuxiliarMainTask {
this.task.setMeasures(measureCollection);
- System.out.println("Evaluation #"+i+" of "+this.numStreamsOption.getValue()+
+ System.out.println("Evaluation #"+(i+1)+" of "+this.numStreamsOption.getValue()+
": "+this.task.getCLICreationString(this.task.getClass()));
//Run task | Corrected status printout in EvaluateMultipleClusterings. | Waikato_moa | train | java |
640515b3f6cad50f1e540aeaccad26dc36d0decb | diff --git a/packages/babel-runtime/scripts/build-dist.js b/packages/babel-runtime/scripts/build-dist.js
index <HASH>..<HASH> 100644
--- a/packages/babel-runtime/scripts/build-dist.js
+++ b/packages/babel-runtime/scripts/build-dist.js
@@ -134,14 +134,6 @@ for (const modules of ["commonjs", false]) {
`${dirname}${helperName}.js`,
buildHelper(helperName, modules, builtin)
);
-
- // compat
- var helperAlias = kebabCase(helperName);
- var content = !modules
- ? `export { default } from \"./${helperName}.js\";`
- : "module.exports = require(\"./" + helperName + ".js\");";
- writeFile(`${dirname}_${helperAlias}.js`, content);
- if (helperAlias !== helperName) writeFile(`${dirname}${helperAlias}.js`, content);
}
}
} | removed unused alias in babel-runtime (#<I>) | babel_babel | train | js |
8ffd7523a47092dc25b3bb2d8322febe45e64a32 | diff --git a/StubsController.php b/StubsController.php
index <HASH>..<HASH> 100644
--- a/StubsController.php
+++ b/StubsController.php
@@ -112,6 +112,25 @@ TPL;
foreach ($components as $name => $classes) {
$classes = implode('|', array_unique($classes));
$stubs .= "\n * @property {$classes} \$$name";
+ if (in_array($name, [
+ 'db',
+ 'log',
+ 'cache',
+ 'formatter',
+ 'request',
+ 'response',
+ 'errorHandler',
+ 'view',
+ 'urlManager',
+ 'i18n',
+ 'authManager',
+ 'assetManager',
+ 'security',
+ 'session',
+ 'user',
+ ])) {
+ $stubs .= "\n * @method {$classes} get" . ucfirst($name) . "()";
+ }
}
$content = str_replace('{stubs}', $stubs, $this->getTemplate()); | Added stubs to methods getRequest(), getUser() and other. (#<I>) | bazilio91_yii2-stubs-generator | train | php |
9a9308823dfce53a5f5e868a7a6fa732c6d13f99 | diff --git a/kite-data/kite-data-core/src/main/java/org/kitesdk/data/partition/ListFieldPartitioner.java b/kite-data/kite-data-core/src/main/java/org/kitesdk/data/partition/ListFieldPartitioner.java
index <HASH>..<HASH> 100644
--- a/kite-data/kite-data-core/src/main/java/org/kitesdk/data/partition/ListFieldPartitioner.java
+++ b/kite-data/kite-data-core/src/main/java/org/kitesdk/data/partition/ListFieldPartitioner.java
@@ -37,15 +37,12 @@ public class ListFieldPartitioner<S> extends FieldPartitioner<S, Integer> {
}
private static <S> int cardinality(List<Set<S>> values) {
- int c = 0;
- for (Set<S> set : values) {
- c += set.size();
- }
- return c;
+ return values.size(); // the number of sets
}
@Override
public Integer apply(S value) {
+ // find the index of the set to which value belongs
for (int i = 0; i < values.size(); i++) {
if (values.get(i).contains(value)) {
return i; | CDK-<I>: Fix ListFieldPartitioner cardinality. | kite-sdk_kite | train | java |
a250a9425151a99ab9a35474164532c53d68e1ae | diff --git a/IPython/html/widgets/widget.py b/IPython/html/widgets/widget.py
index <HASH>..<HASH> 100644
--- a/IPython/html/widgets/widget.py
+++ b/IPython/html/widgets/widget.py
@@ -84,14 +84,22 @@ class BaseWidget(LoggingConfigurable):
removed from the frontend."""
self._close_communication()
-
+ _keys = ['default_view_name']
+
# Properties
@property
def keys(self):
- keys = ['default_view_name']
- keys.extend(self._keys)
+ """Lazily accumulate _keys from all superclasses and cache them in this class"""
+ keys=[]
+ for c in self.__class__.mro():
+ if hasattr(c, '_keys'):
+ keys.extend(getattr(c,'_keys'))
+ else:
+ break
+ # cache so future lookups are fast
+ self.__class__.x = keys
return keys
-
+
@property
def comm(self):
if self._comm is None:
@@ -346,12 +354,7 @@ class Widget(BaseWidget):
# Private/protected declarations
_css = Dict() # Internal CSS property dict
- # Properties
- @property
- def keys(self):
- keys = ['visible', '_css']
- keys.extend(super(Widget, self).keys)
- return keys
+ _keys = ['visible', '_css']
def get_css(self, key, selector=""):
"""Get a CSS property of the widget. Note, this function does not | Make the widget keys property traverse the superclasses and accumulate the _keys attributes.
This caches the result, overwriting the property. | jupyter-widgets_ipywidgets | train | py |
04bebe44c33ad5776b919ef41798efac4e6d6a6a | diff --git a/lib/utils/copyEvents.js b/lib/utils/copyEvents.js
index <HASH>..<HASH> 100644
--- a/lib/utils/copyEvents.js
+++ b/lib/utils/copyEvents.js
@@ -6,6 +6,7 @@ const _ = require('lodash');
module.exports = function copyEvents(from, to) {
// Clone all events
_.each(from._events, function(events, eventName) {
+ events = Array.isArray(events) ? events : [events];
_.each(events, function(event) {
to.on(eventName, event);
}); | fix events will not be copied when there is only one | baijijs_baiji | train | js |
9862b12ce968389e866a94ca6e6a34add9336db9 | diff --git a/ftfy/fixes.py b/ftfy/fixes.py
index <HASH>..<HASH> 100644
--- a/ftfy/fixes.py
+++ b/ftfy/fixes.py
@@ -210,11 +210,13 @@ def fix_text_and_explain(text):
steps = [('encode', 'latin-1'), ('decode', 'windows-1252')]
return fixed, steps
except UnicodeDecodeError:
- # Well, never mind.
+ # This text contained characters that don't even make sense
+ # if you assume they were supposed to be Windows-1252. In
+ # that case, let's not assume anything.
pass
# The cases that remain are mixups between two different single-byte
- # encodings, neither of which is Latin-1.
+ # encodings, and not the common case of Latin-1 vs. Windows-1252.
#
# Those cases are somewhat rare, and impossible to solve without false
# positives. If you're in one of these situations, you don't need an | Document the case where we give up on decoding text as Windows-<I>.
This includes fixing an inaccurate comment that appeared after it. | LuminosoInsight_python-ftfy | train | py |
52f557771f368817e101f23e5caa039d369cc08a | diff --git a/fireplace/card.py b/fireplace/card.py
index <HASH>..<HASH> 100644
--- a/fireplace/card.py
+++ b/fireplace/card.py
@@ -91,7 +91,6 @@ class BaseCard(Entity):
type = _TAG(GameTag.CARDTYPE, CardType.INVALID)
aura = _TAG(GameTag.AURA, False)
controller = _TAG(GameTag.CONTROLLER, None)
- exhausted = _TAG(GameTag.EXHAUSTED, False)
hasDeathrattle = _PROPERTY(GameTag.DEATHRATTLE, False)
isValidTarget = targeting.isValidTarget
@@ -200,6 +199,7 @@ class BaseCard(Entity):
class PlayableCard(BaseCard):
+ exhausted = _TAG(GameTag.EXHAUSTED, False)
freeze = _TAG(GameTag.FREEZE, False)
hasBattlecry = _TAG(GameTag.BATTLECRY, False)
hasCombo = _TAG(GameTag.COMBO, False) | Move exhausted tag to PlayableCard | jleclanche_fireplace | train | py |
c9ca60e11f83593e97567b478d057e36d9dc70d5 | diff --git a/hazelcast-wm/src/main/java/com/hazelcast/web/WebFilter.java b/hazelcast-wm/src/main/java/com/hazelcast/web/WebFilter.java
index <HASH>..<HASH> 100644
--- a/hazelcast-wm/src/main/java/com/hazelcast/web/WebFilter.java
+++ b/hazelcast-wm/src/main/java/com/hazelcast/web/WebFilter.java
@@ -535,7 +535,8 @@ public class WebFilter implements Filter {
throw new NullPointerException("name must not be null");
}
if (value == null) {
- throw new IllegalArgumentException("value must not be null");
+ removeAttribute(name);
+ return;
}
if (deferredWrite) {
LocalCacheEntry entry = localCache.get(name); | backport for issue #<I> | hazelcast_hazelcast | train | java |
34f56ab32c8ddf482884f535c631cba341d9127a | diff --git a/calligraphy/src/main/java/uk/co/chrisjenx/calligraphy/CalligraphyFactory.java b/calligraphy/src/main/java/uk/co/chrisjenx/calligraphy/CalligraphyFactory.java
index <HASH>..<HASH> 100644
--- a/calligraphy/src/main/java/uk/co/chrisjenx/calligraphy/CalligraphyFactory.java
+++ b/calligraphy/src/main/java/uk/co/chrisjenx/calligraphy/CalligraphyFactory.java
@@ -170,8 +170,8 @@ class CalligraphyFactory {
mToolbarReference = new WeakReference<>(toolbar);
orignalTitle = toolbar.getTitle();
orignalSubTitle = toolbar.getSubtitle();
- toolbar.setTitle("Title");
- toolbar.setSubtitle("SubTitle");
+ toolbar.setTitle(" ");
+ toolbar.setSubtitle(" ");
}
@TargetApi(Build.VERSION_CODES.JELLY_BEAN) | use whitespace just incase the user does something weird | chrisjenx_Calligraphy | train | java |
d4b883c53bc622e01d5582f6ff754ef9a8c001ad | diff --git a/src/BotApi.php b/src/BotApi.php
index <HASH>..<HASH> 100644
--- a/src/BotApi.php
+++ b/src/BotApi.php
@@ -277,7 +277,7 @@ class BotApi
/**
* Use this method to send text messages. On success, the sent \TelegramBot\Api\Types\Message is returned.
*
- * @param int $chatId
+ * @param int|string $chatId
* @param string $text
* @param string|null $parseMode
* @param bool $disablePreview
@@ -297,7 +297,7 @@ class BotApi
$replyMarkup = null
) {
return Message::fromResponse($this->call('sendMessage', [
- 'chat_id' => (int) $chatId,
+ 'chat_id' => $chatId,
'text' => $text,
'parse_mode' => $parseMode,
'disable_web_page_preview' => $disablePreview, | fixes for issues #<I> and #<I> | TelegramBot_Api | train | php |
54fc3c50970bef7eebd868128c43f2e615364453 | diff --git a/src/Commands/PackageClone.php b/src/Commands/PackageClone.php
index <HASH>..<HASH> 100644
--- a/src/Commands/PackageClone.php
+++ b/src/Commands/PackageClone.php
@@ -91,7 +91,12 @@ class PackageClone extends Command
if (Str::contains($url, '@')) {
$vendorAndPackage = explode(':', $url);
- return explode('/', $vendorAndPackage[1]);
+ $vendorAndPackage = explode('/', $vendorAndPackage[1]);
+
+ return [
+ $vendorAndPackage[0],
+ Str::replaceLast('.git', '', $vendorAndPackage[1]),
+ ];
}
$urlParts = explode('/', $url); | fix bug with clone url with .git on the end | melihovv_laravel-package-generator | train | php |
c9c285739b24d3491c22c873ec57b56770803ed3 | diff --git a/lib/discordrb/gateway.rb b/lib/discordrb/gateway.rb
index <HASH>..<HASH> 100644
--- a/lib/discordrb/gateway.rb
+++ b/lib/discordrb/gateway.rb
@@ -278,5 +278,17 @@ module Discordrb
def handle_message(msg)
end
+
+ def send(data, opt = { type: :text })
+ return if !@handshaked || @closed
+ type = opt[:type]
+ frame = ::WebSocket::Frame::Outgoing::Client.new(data: data, type: type, version: @handshake.version)
+ begin
+ @socket.write frame.to_s
+ rescue Errno::EPIPE => e
+ @pipe_broken = true
+ emit :__close, e
+ end
+ end
end
end | Copy over WSCS' send method | meew0_discordrb | train | rb |
a0f3ab9ecdc8736f258744f962b9284a0372f40b | diff --git a/test/legacy/node-8/main.js b/test/legacy/node-8/main.js
index <HASH>..<HASH> 100644
--- a/test/legacy/node-8/main.js
+++ b/test/legacy/node-8/main.js
@@ -67,6 +67,11 @@ testArbitrary(fc.float({ next: true, noNaN: true })); // NaN is not properly rec
testArbitrary(fc.double({ next: true, noNaN: true }));
testArbitrary(fc.emailAddress());
testArbitrary(fc.webUrl());
+testArbitrary(fc.int8Array());
+testArbitrary(fc.int16Array());
+testArbitrary(fc.int32Array());
+testArbitrary(fc.float32Array());
+testArbitrary(fc.float64Array());
testArbitrary(
fc.mapToConstant(
{ | ✅ Add legacy tests for typed arrays (#<I>) | dubzzz_fast-check | train | js |
31a2a46f2621a0c56a5374a7262184e9b23ceb61 | diff --git a/jsoup/src/main/java/org/hobsoft/microbrowser/jsoup/JsoupForm.java b/jsoup/src/main/java/org/hobsoft/microbrowser/jsoup/JsoupForm.java
index <HASH>..<HASH> 100644
--- a/jsoup/src/main/java/org/hobsoft/microbrowser/jsoup/JsoupForm.java
+++ b/jsoup/src/main/java/org/hobsoft/microbrowser/jsoup/JsoupForm.java
@@ -165,7 +165,7 @@ class JsoupForm implements Form
}
else
{
- action = element.ownerDocument().baseUri();
+ action = element.baseUri();
}
return newUrlOrNull(action); | Simplify obtaining form's base URI | markhobson_microbrowser | train | java |
6e0fdbc86cf24268e32e7db01164edc642ed13a7 | diff --git a/sesame/test_backends.py b/sesame/test_backends.py
index <HASH>..<HASH> 100644
--- a/sesame/test_backends.py
+++ b/sesame/test_backends.py
@@ -75,15 +75,6 @@ class TestModelBackend(TestCase):
self.assertEqual(user, None)
self.assertIn("Invalid token", self.get_log())
- def test_type_error_is_logged(self):
- def raise_type_error(*args):
- raise TypeError
-
- self.backend.parse_token = raise_type_error
- with self.assertRaises(TypeError):
- self.backend.authenticate(request=None, url_auth_token=None)
- self.assertIn("TypeError", self.get_log())
-
def test_naive_token_hijacking_fails(self):
# Tokens contain the PK of the user, the hash of the revocation key,
# and a signature. The revocation key may be identical for two users: | Remove test forgotten in <I>dd<I>. | aaugustin_django-sesame | train | py |
2a83d6da01156263922be0c206fe717bfe8cbff2 | diff --git a/src/main/java/io/appium/java_client/MobileBy.java b/src/main/java/io/appium/java_client/MobileBy.java
index <HASH>..<HASH> 100644
--- a/src/main/java/io/appium/java_client/MobileBy.java
+++ b/src/main/java/io/appium/java_client/MobileBy.java
@@ -102,9 +102,13 @@ public abstract class MobileBy extends By {
* @param iOSNsPredicateString is an an iOS NsPredicate String
* @return an instance of {@link io.appium.java_client.MobileBy.ByIosNsPredicate}
*/
- public static By IosNsPredicateString(final String iOSNsPredicateString) {
+ public static By iOSNsPredicateString(final String iOSNsPredicateString) {
return new ByIosNsPredicate(iOSNsPredicateString);
}
+
+ public static By windowsAutomation(final String windowsAutomation) {
+ return new ByWindowsAutomation(windowsAutomation);
+ }
public static class ByIosUIAutomation extends MobileBy implements Serializable { | #<I> fix. Issues that found by Codecy were fixed | appium_java-client | train | java |
7abd45f02df02dc45cd95671deb980d9286bea93 | diff --git a/pipenv/environments.py b/pipenv/environments.py
index <HASH>..<HASH> 100644
--- a/pipenv/environments.py
+++ b/pipenv/environments.py
@@ -25,12 +25,6 @@ Some people don't like colors in their terminals, for some reason. Default is
to show colors.
"""
-PIPENV_VERBOSITY = int(os.environ.get("PIPENV_VERBOSITY", "0"))
-"""Verbosity setting for pipenv. Higher values make pipenv less verbose.
-
-Default is 0, for maximum verbosity.
-"""
-
# Tells Pipenv which Python to default to, when none is provided.
PIPENV_DEFAULT_PYTHON_VERSION = os.environ.get("PIPENV_DEFAULT_PYTHON_VERSION")
"""Use this Python version when creating new virtual environments by default.
@@ -180,6 +174,12 @@ PIPENV_VENV_IN_PROJECT = bool(os.environ.get("PIPENV_VENV_IN_PROJECT"))
Default is to create new virtual environments in a global location.
"""
+PIPENV_VERBOSITY = int(os.environ.get("PIPENV_VERBOSITY", "0"))
+"""Verbosity setting for pipenv. Higher values make pipenv less verbose.
+
+Default is 0, for maximum verbosity.
+"""
+
PIPENV_YES = bool(os.environ.get("PIPENV_YES"))
"""If set, Pipenv automatically assumes "yes" at all prompts. | Move PIPENV_VERBOSITY to correct place in alphabet
Oops. | pypa_pipenv | train | py |
de4fe94485fa20698d8b906d69db9e2dea71878c | diff --git a/core-bundle/contao/library/Contao/Model/QueryBuilder.php b/core-bundle/contao/library/Contao/Model/QueryBuilder.php
index <HASH>..<HASH> 100644
--- a/core-bundle/contao/library/Contao/Model/QueryBuilder.php
+++ b/core-bundle/contao/library/Contao/Model/QueryBuilder.php
@@ -83,6 +83,12 @@ class QueryBuilder
$strQuery .= " GROUP BY " . $arrOptions['group'];
}
+ // Having (see #6446)
+ if ($arrOptions['having'] !== null)
+ {
+ $strQuery .= " HAVING " . $arrOptions['having'];
+ }
+
// Order by
if ($arrOptions['order'] !== null)
{ | [Core] Support the "HAVING" command in the `Model\QueryBuilder` class (see #<I>) | contao_contao | train | php |
7c04bfc4a5411ae32185484c278ae6c2b4f20b87 | diff --git a/api/src/main/java/org/telegram/botapi/api/chat/Chat.java b/api/src/main/java/org/telegram/botapi/api/chat/Chat.java
index <HASH>..<HASH> 100644
--- a/api/src/main/java/org/telegram/botapi/api/chat/Chat.java
+++ b/api/src/main/java/org/telegram/botapi/api/chat/Chat.java
@@ -1,5 +1,6 @@
package org.telegram.botapi.api.chat;
+import org.telegram.botapi.api.TelegramBot;
import org.telegram.botapi.api.chat.message.Message;
import org.telegram.botapi.api.chat.message.send.SendableMessage;
import org.telegram.botapi.api.chat.message.send.SendableTextMessage;
@@ -11,10 +12,10 @@ public interface Chat {
int getId();
- default Message sendMessage(String message) {
+ default Message sendMessage(String message, TelegramBot telegramBot) {
- return this.sendMessage(SendableTextMessage.builder().message(message).build());
+ return this.sendMessage(SendableTextMessage.builder().message(message).build(), telegramBot);
}
- Message sendMessage(SendableMessage message);
+ Message sendMessage(SendableMessage message, TelegramBot telegramBot);
}
\ No newline at end of file | Changed Chat#sendMessage(String) and Chat#sendMessage(SendableMessage) to include a TelegramBot argument in order to support multiple bots in one program | zackpollard_JavaTelegramBot-API | train | java |
198e19ee0773e1d03a21291314ce29fe7c87892d | diff --git a/src/libs/customelement.js b/src/libs/customelement.js
index <HASH>..<HASH> 100644
--- a/src/libs/customelement.js
+++ b/src/libs/customelement.js
@@ -29,14 +29,6 @@ export default class CustomElement {
// create static factory method for creating dominstance
ComponentClass.create = function($create_vars = null){
- // override constructor
- /**
- * Nativ CustomElements doesnt allow to use a constructor
- * therefore if constructor is added by the user we override that
- * otherwise an error could be thrown.
- *
- */
- this.constructor = function(){};
// extract and assign instance properties
/** | customelement.js: removed unnecessary code | SerkanSipahi_app-decorators | train | js |
75557a6ff6dd568d3e7129d20c209a730a598cff | diff --git a/src/canari/unittests/maltego/entities.py b/src/canari/unittests/maltego/entities.py
index <HASH>..<HASH> 100644
--- a/src/canari/unittests/maltego/entities.py
+++ b/src/canari/unittests/maltego/entities.py
@@ -1,6 +1,6 @@
from datetime import date, datetime, timedelta
from canari.maltego.message import Entity, Field, StringEntityField, IntegerEntityField, FloatEntityField, \
- BooleanEntityField, EnumEntityField, LongEntityField, DateTimeEntityField, DateEntityField, timespan, \
+ BooleanEntityField, EnumEntityField, LongEntityField, DateTimeEntityField, DateEntityField, TimeSpan, \
TimeSpanEntityField, RegexEntityField, ColorEntityField
from unittest import TestCase | Old entities unittests need to update | redcanari_canari3 | train | py |
d3de7b6e8214803917864cc8b1ee65983d25b423 | diff --git a/core/Common.php b/core/Common.php
index <HASH>..<HASH> 100644
--- a/core/Common.php
+++ b/core/Common.php
@@ -471,7 +471,13 @@ class Common
$ok = false;
if ($varType === 'string') {
- if (is_string($value)) $ok = true;
+ if (is_string($value) || is_int($value)) {
+ $ok = true;
+ } else if (is_float($value)) {
+ $value = Common::forceDotAsSeparatorForDecimalPoint($value);
+ $ok = true;
+ }
+
} elseif ($varType === 'integer') {
if ($value == (string)(int)$value) $ok = true;
} elseif ($varType === 'float') { | do not lose value in case it is an integer or a float. Instead convert it to a string.
Eg this returned the default value in the past: `Common::getRequestVar('param', 'string', 'default', array('param' => 5))` which can happen eg in BulkTracking etc. causing many values not to be tracked. Wondering if it breaks anything. | matomo-org_matomo | train | php |
12ac20e1e146aed7276df953d27be1c57d034785 | diff --git a/lib/cucumber/cli/options.rb b/lib/cucumber/cli/options.rb
index <HASH>..<HASH> 100644
--- a/lib/cucumber/cli/options.rb
+++ b/lib/cucumber/cli/options.rb
@@ -27,7 +27,7 @@ module Cucumber
max = BUILTIN_FORMATS.keys.map{|s| s.length}.max
FORMAT_HELP = (BUILTIN_FORMATS.keys.sort.map do |key|
" #{key}#{' ' * (max - key.length)} : #{BUILTIN_FORMATS[key][1]}"
- end) + ["Use --format rerun --out features.txt to write out failing",
+ end) + ["Use --format rerun --out rerun.txt to write out failing",
"features. You can rerun them with cucumber @rerun.txt.",
"FORMAT can also be the fully qualified class name of",
"your own custom formatter. If the class isn't loaded,", | Incorrect help text was bothering me. | cucumber_cucumber-ruby | train | rb |
760dbd1312bac14dd8402ab68c529ba0cb46fdd7 | diff --git a/quarkc/command.py b/quarkc/command.py
index <HASH>..<HASH> 100644
--- a/quarkc/command.py
+++ b/quarkc/command.py
@@ -219,6 +219,7 @@ def main(args):
else:
assert False
except compiler.QuarkError as err:
+ command_log.warn("")
return err
command_log.warn("Done") | Flush progress bar in case of compile errors | datawire_quark | train | py |
663a897670f1f23623e5a6c5017f019bd4aa9b29 | diff --git a/src/eth/NonceService.js b/src/eth/NonceService.js
index <HASH>..<HASH> 100644
--- a/src/eth/NonceService.js
+++ b/src/eth/NonceService.js
@@ -26,7 +26,8 @@ export default class NonceService extends PublicService {
getNonce() {
return this.get('web3')._web3.eth.getTransactionCount(
- this.get('web3').defaultAccount()
+ this.get('web3').defaultAccount(),
+ 'pending'
);
}
} | Include pending transactions in web3 count query | makerdao_dai.js | train | js |
09ec8ca396daf988deec58199894b5c7f45a2ec7 | diff --git a/test_load_paul_pubring.py b/test_load_paul_pubring.py
index <HASH>..<HASH> 100644
--- a/test_load_paul_pubring.py
+++ b/test_load_paul_pubring.py
@@ -72,7 +72,12 @@ pb3w = [PacketCounter(packets), '|', Timer("%s"), '|', Percentage(), Bar()]
pbar3 = ProgressBar(maxval=_mv, widgets=pb3w).start()
while len(_b) > 0:
- packets.append(Packet(_b))
+ olen = len(_b)
+ pkt = Packet(_b)
+ if (olen - len(_b)) != len(pkt.header) + pkt.header.length:
+ print("Incorrect number of bytes consumed. Got: {:,}. Expected: {:,}".format((olen - len(_b)), (len(pkt.header) + pkt.header.length)))
+ print("Bad packet was: {cls:s}, {id:d}, {ver:s}".format(cls=pkt.__class__.__name__, id=pkt.header.typeid, ver=str(pkt.header.version) if hasattr(pkt.header, 'version') else ''))
+ packets.append(pkt)
pbar3.update(_mv - len(_b))
pbar3.finish() | added some helpful error output to benchmark script | SecurityInnovation_PGPy | train | py |
4bf414e67a6620d6877eb85ac822bd894d59ba7d | diff --git a/src/test/java/com/suse/salt/netapi/examples/GitModule.java b/src/test/java/com/suse/salt/netapi/examples/GitModule.java
index <HASH>..<HASH> 100644
--- a/src/test/java/com/suse/salt/netapi/examples/GitModule.java
+++ b/src/test/java/com/suse/salt/netapi/examples/GitModule.java
@@ -30,8 +30,8 @@ public class GitModule {
private static final String HTTPS_PASS = "saltgit";
public static void main(String[] args) {
- // Init the client
- SaltClient client =
+ // the client
+ SaltClient client =
new SaltClient(URI.create(SALT_API_URL),
new HttpAsyncClientImpl(HttpClientUtils.defaultClient()));
Token token = client.login(USER, PASSWORD, AuthModule.PAM).toCompletableFuture().join();
@@ -48,7 +48,7 @@ public class GitModule {
// substitute above line for the below line of no user and password
// Optional.empty(), Optional.empty(), Optional.empty());
- Map<String, Result<Boolean>> results =
+ Map<String, Result<Boolean>> results =
call.callSync(client, new MinionList(MINION_ID), tokenAuth).toCompletableFuture().join();
System.out.println("Response from minions:"); | Remove tabs at the beguinning of the line. | SUSE_salt-netapi-client | train | java |
db588f8727ad83c0204c9624e92d878a912fc811 | diff --git a/lib/flapjack/processor.rb b/lib/flapjack/processor.rb
index <HASH>..<HASH> 100755
--- a/lib/flapjack/processor.rb
+++ b/lib/flapjack/processor.rb
@@ -86,7 +86,7 @@ module Flapjack
redis_version = Flapjack.redis.info['redis_version']
required_version = '2.6.12'
- raise "Redis too old - Flapjack requires #{required_version} but #{redis_version} is running" if Gem::Version.new(redis_version) < Gem::Version.new(required_version)
+ raise "Redis too old - Flapjack requires #{required_version} but #{redis_version} is running" if redis_version && Gem::Version.new(redis_version) < Gem::Version.new(required_version)
# FIXME: add an administrative function to reset all event counters | Only exit if we were able to detect redis' current version | flapjack_flapjack | train | rb |
0cebffa1f6d20c6891d18bcd1f0c0c4c63a7761f | diff --git a/bucket/option/put.go b/bucket/option/put.go
index <HASH>..<HASH> 100644
--- a/bucket/option/put.go
+++ b/bucket/option/put.go
@@ -13,6 +13,7 @@ type PutObjectInput func(req *s3.PutObjectInput)
func SSEKMSKeyID(keyID string) PutObjectInput {
return func(req *s3.PutObjectInput) {
req.SSEKMSKeyId = aws.String(keyID)
+ req.ServerSideEncryption = aws.String("aws:kms")
}
} | bucket: Set ServerSideEncryption = "aws:kms" | nabeken_aws-go-s3 | train | go |
013186cc8a0714faf370c38bd26aaf541e15c682 | diff --git a/definitions/npm/koa_v2.x.x/flow_v0.94.x-/koa_v2.x.x.js b/definitions/npm/koa_v2.x.x/flow_v0.94.x-/koa_v2.x.x.js
index <HASH>..<HASH> 100644
--- a/definitions/npm/koa_v2.x.x/flow_v0.94.x-/koa_v2.x.x.js
+++ b/definitions/npm/koa_v2.x.x/flow_v0.94.x-/koa_v2.x.x.js
@@ -8,7 +8,7 @@
* breaking: ctx.throw([status], [msg], [properties]) (caused by http-errors (#957) )
**/
declare module 'koa' {
- declare type JSON = | string | number | boolean | null | JSONObject | JSONArray;
+ declare type JSON = | string | number | boolean | null | void | JSONObject | JSONArray;
declare type JSONObject = { [key: string]: JSON };
declare type JSONArray = Array<JSON>;
@@ -209,7 +209,7 @@ declare module 'koa' {
res: http$ServerResponse,
respond?: boolean, // should not be used, allow bypassing koa application.js#L193
response: Response,
- state: {},
+ state: {[string]: any},
// context.js#L55
assert: (test: mixed, status: number, message?: string, opts?: mixed) => void, | [koa_v2.x.x.js] Update object types (#<I>)
* Update koa types
* Change undefined to void | flow-typed_flow-typed | train | js |
2a8b097e35f2ac69743eb1bed44c3324c93ebe8c | diff --git a/faker/providers/person/en_GB/__init__.py b/faker/providers/person/en_GB/__init__.py
index <HASH>..<HASH> 100644
--- a/faker/providers/person/en_GB/__init__.py
+++ b/faker/providers/person/en_GB/__init__.py
@@ -588,5 +588,5 @@ class Provider(PersonProvider):
('Watkins', 0.06),
))
- prefixes_female = ('Mrs.', 'Ms.', 'Miss', 'Dr.')
- prefixes_male = ('Mr.', 'Dr.')
+ prefixes_female = ('Mrs', 'Ms', 'Miss', 'Dr')
+ prefixes_male = ('Mr', 'Dr') | Remove period/fullstop from en_GB prefixes (#<I>) | joke2k_faker | train | py |
08f05376cf7dd970a25853a6823c5a4bfff174a1 | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -27,7 +27,7 @@ setup(
long_description=_get_description(),
long_description_content_type="text/markdown",
install_requires=["Django>=1.11,<2.3", "psycopg2-binary"],
- extras_require={"development": ["python-coveralls", "mkdocs"]},
+ extras_require={"development": ["coveralls", "mkdocs"]},
classifiers=[
"Framework :: Django",
"Framework :: Django :: 1.11", | python-coveralls --> coveralls | DemocracyClub_uk-geo-utils | train | py |
ec86da58701372a93c233b60eb9efd1ac69d012a | diff --git a/pycbc/libutils.py b/pycbc/libutils.py
index <HASH>..<HASH> 100644
--- a/pycbc/libutils.py
+++ b/pycbc/libutils.py
@@ -39,7 +39,7 @@ def pkg_config_libdirs(packages):
raise ValueError("Package {0} cannot be found on the pkg-config search path".format(pkg))
libdirs = []
- for token in commands.getoutput("PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1 pkg-config --libs-only-L {0}".format(' '.join(packages))).split():
+ for token in commands.getoutput("PKG_CONFIG_ALLOW_SYSTEM_LIBS=1 pkg-config --libs-only-L {0}".format(' '.join(packages))).split():
if token.startswith("-L"):
libdirs.append(token[2:])
return libdirs | Fix pycbc.libutils.pkg_config_libdirs to properly include system installs | gwastro_pycbc | train | py |
Subsets and Splits
--- a/Listener/TaggedEntityListener.php
+++ b/Listener/TaggedEntityListener.php
@@ -54,11 +54,11 @@ class TaggedEntityListener implements EventSubscriber
}
/**
* Post remove event handler.
*
* @param LifecycleEventArgs $eventArgs
*/
- public function postRemove(LifecycleEventArgs $eventArgs)
+ public function preRemove(LifecycleEventArgs $eventArgs)
{
$entity = $eventArgs->getObject();
@@ -70,9 +70,9 @@ class TaggedEntityListener implements EventSubscriber
/**
* Post flush event handler.
*
- * @param PostFlushEventArgs $args
+ * @param PostFlushEventArgs $eventArgs
*/
- public function postFlush(PostFlushEventArgs $args)
+ public function postFlush(PostFlushEventArgs $eventArgs)
{
$this->eventDispatcher->dispatch(
HttpCacheEvents::INVALIDATE_TAG,
@@ -108,7 +108,7 @@ class TaggedEntityListener implements EventSubscriber
{
return array(
Events::postUpdate,
- Events::postRemove,
+ Events::preRemove,
Events::postFlush,
);
} | Fix TaggedEntity listener
@@ -54,11 +54,11 @@ class TaggedEntityListener implements EventSubscriber
}
/**
- * Post remove event handler.
+ * Pre remove event handler.
*
* @param LifecycleEventArgs $eventArgs
Use preRemove instead of postRemove because id was never available | ekyna_CoreBundle | train | php |
25ac7a7801d7b582773ad8cddf1af980417e39f0 | diff --git a/spec/circleci/cli/command/base_command_spec.rb b/spec/circleci/cli/command/base_command_spec.rb
index <HASH>..<HASH> 100644